import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from '@nestjs/common';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { Constants } from 'src/utils/constants';
import { ContactModelService } from './contact-model.service';
import { CreateContactModelDto } from './dto/create-contact-model.dto';
import { UpdateContactModelDto } from './dto/update-contact-model.dto';

@Controller({ path: 'contact-model', version: Constants.API_VERSION_1 })
export class ContactModelController {
    constructor(private readonly service: ContactModelService) {}

    @Post()
    create(@Body() dto: CreateContactModelDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateContactModelDto) {
        return this.service.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
