import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { PurchaseAndDeliveryPolicyService } from "./purchase-and-delivery-policy.service";
import { CreatePurchaseAndDeliveryPolicyDto } from "./dto/create-purchase-and-delivery-policy.dto";
import { UpdatePurchaseAndDeliveryPolicyDto } from "./dto/update-purchase-and-delivery-policy.dto";

@Controller({ path: "purchase-and-delivery-policy", version: Constants.API_VERSION_1 })

export class PurchaseAndDeliveryPolicyController {
    constructor(private readonly service: PurchaseAndDeliveryPolicyService) {}

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreatePurchaseAndDeliveryPolicyDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(@Param("id") id: string, @Body() dto: UpdatePurchaseAndDeliveryPolicyDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
