import {
    Body,
    Controller,
    Delete,
    Get,
    HttpCode,
    HttpStatus,
    Param,
    Patch,
    Post,
    Query,
    Req,
    UseGuards
} from '@nestjs/common';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {AuthGuard} from 'src/core/guards/auth.guard';
import {Constants} from 'src/utils/constants';
import {CreateOrderByAdminDto} from './dto/create-order-by-admin.dto';
import {CreateOrderByGuestDto} from './dto/create-order-by-guest.dto';
import {CreateOrderDto} from './dto/create-order.dto';
import {UpdateOrderDto} from './dto/update-order.dto';
import {OrdersService} from './orders.service';

@Controller({path: 'orders', version: Constants.API_VERSION_1})
export class OrdersController {
    constructor(private readonly ordersService: OrdersService) {
    }

    @Post()
    @UseGuards(AuthGuard)
    create(@Body() createOrderDto: CreateOrderDto, @Req() req: any) {
        return this.ordersService.create(createOrderDto, req.user);
    }

    @Post('/admin')
    @UseGuards(AdminAuthGuard)
    createOrderByAdmin(@Body() createOrderByAdminDto: CreateOrderByAdminDto, @Req() req: any) {
        return this.ordersService.createOrderByAdmin(createOrderByAdminDto, req.user);
    }

    @Post('/guest')
    createOrderByGuest(@Body() dto: CreateOrderByGuestDto) {
        return this.ordersService.createOrderByGuest(dto);
    }

    @Post('/validate-shipping')
    @HttpCode(HttpStatus.OK)
    validateShipping(@Body() dto: any) {
        return this.ordersService.validateShipping(dto);
    }

    @Post('update-tracking-no')
    @HttpCode(HttpStatus.OK)
    updateOrderTracking(@Body() dto: any) {
        console.log(dto);
        return this.ordersService.updateOrderTracking(dto);
    }


    @Get()
    @UseGuards(AdminAuthGuard)
    async findAll(
        @Query('limit') limit: number,
        @Query('page') page: number,
        @Query('paymentStatus') paymentStatus?: string,
        @Query('deliveryStatus') deliveryStatus?: string,
        @Query('startDate') startDate?: Date,
        @Query('endDate') endDate?: Date,
        @Query('customerName') customerName?: string,
        @Query('orderId') orderId?: string
    ) {
        return await this.ordersService.findAll(limit, page, paymentStatus, deliveryStatus, startDate, endDate, customerName, orderId);
    }

    @Get('/filter')
    @UseGuards(AuthGuard)
    async findOrderByFilter(
        @Req() authUser: any,
        @Query('limit') limit: number,
        @Query('page') page: number,
        @Query('tabStatus') tabStatus: string
    ) {
        return await this.ordersService.findOrderByFilter(authUser, limit, page, tabStatus);
    }

    @Get('/profit')
    // @UseGuards(AuthGuard)
    async getOrderProfit(
        @Query('limit') limit: number,
        @Query('page') page: number,
        @Query('startDate') startDate?: Date,
        @Query('endDate') endDate?: Date,
        @Query('orderId') orderId?: string
    ) {
        return await this.ordersService.orderProfitService(limit, page, startDate, endDate, orderId);
    }

    @Get('/get-orderid')
    @UseGuards(AdminAuthGuard)
    getOrderId() {
        return this.ordersService.getOrderId();
    }


    @Get('/check-orderid/:id')
    checkOrderId(@Param('id') id: string) {
        return this.ordersService.checkOrderId(id);
    }

    @Get('/details-without-guard/:id')
    async detailsWithoutGuard(@Param('id') id: string) {
        //console.log('id =', id);
        //return id;
        return await this.ordersService.findOneOrderByOrderID(id);
    }

    @Get('/:id')
    @UseGuards(AuthGuard)
    async findOne(@Param('id') id: string) {
        return await this.ordersService.findOne(id);
    }

    @Patch('/shipping-label/:id')
    createShippingLabel(@Param('id') id: string, @Body() dto: any) {
        return this.ordersService.createShippingLabel(id, dto);
    }

    @Patch('/:id')
    update(@Param('id') id: string, @Body() dto: UpdateOrderDto) {
        return this.ordersService.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.ordersService.remove(id);
    }
}
