import {Body, Controller, Delete, Get, HttpCode, HttpStatus, Param, Patch, Post, Req, UseGuards} from '@nestjs/common';
import {Constants} from 'src/utils/constants';
import {StripeService} from './stripe.service';
import { CreateStripeDto } from './dto/create-stripe.dto';

@Controller({path: 'stripe', version: Constants.API_VERSION_1})
export class StripeController {
    constructor(private readonly service: StripeService) {}

    @Post('webhook')
    @HttpCode(HttpStatus.OK)
    handleStripeWebhook(@Body() dto: CreateStripeDto) {
        // const sig = request.headers['stripe-signature'] as string;
        // this.service.handleWebhook(payload, sig);
        //console.log('payload =', sto);
        return this.service.handleWebhook(dto);
        //return new Date();
        
    }

    @Get('session-status/:sessionId')
    async verifySession(@Param('sessionId') sessionId: string) {
        const session = await this.service.verifyCheckoutSession(sessionId);
        return { session };
    }

    @Get('checkout-sess-status/:checkoutId')
    async verifyCheckoutSession(@Param('checkoutId') checkoutId: string) {
        const session = await this.service.verifyCheckout(checkoutId);
        return session;
    }

    @Get('checkout-cancel-status/:checkoutId')
    async cancelSession(@Param('checkoutId') checkoutId: string) {
        const session = await this.service.cancelCheckoutSession(checkoutId);
        return session;
    }

    @Get('checkout-refund-action/:paymentIntentId/:orderDBID')
    async refundPayment(@Param('paymentIntentId') paymentIntentId: string, @Param('orderDBID') orderDBID: string) {
        const session = await this.service.refundPayment(paymentIntentId,orderDBID);
        return session;
    }

    @Get('checkout-partial-refund-action/:paymentIntentId/:amount')
    async partialRefundPayment(@Param('paymentIntentId') paymentIntentId: string, @Param('amount') amount: number) {
        const session = await this.service.partialRefund(paymentIntentId, amount);
        return session;
    }

    @Get('checkout-cancel-action/:paymentIntentId')
    async cancelPayment(@Param('paymentIntentId') paymentIntentId: string) {
        const session = await this.service.cancelPaymentIntent(paymentIntentId);
        return session;
    }
  

    @Post('/checkout-new-session')
    createNewCheckoutSession(@Body() dto: any) {
        const data = this.service.createCheckoutSession(dto);
        return data;
    }
}
