import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UseGuards
} from '@nestjs/common';
import { Constants } from 'src/utils/constants';
import { BrandService } from './brand.service';
import { CreateBrandDto } from './dto/create-brand.dto';
import { UpdateBrandDto } from './dto/update-brand.dto';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';

@Controller({
    path: 'brand',
    version: Constants.API_VERSION_1
})
export class BrandController {
    constructor(private readonly brandService: BrandService) {}

    @Post()
    @UseGuards(AdminAuthGuard)
    create(
        @Body() dto: CreateBrandDto
    ) {
        return this.brandService.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.brandService.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.brandService.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    update(
        @Param('id') id: string,
        @Body() dto: UpdateBrandDto
    ) {
        return this.brandService.update(id, dto);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    remove(@Param('id') id: string) {
        return this.brandService.remove(id);
    }
}
