import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateBrandDto } from "./dto/create-brand.dto";
import { UpdateBrandDto } from "./dto/update-brand.dto";
import { Brand } from "./entity/brand.entity";

@EntityRepository(Brand)
export class BrandRepository extends Repository<Brand> {

    async createEntity(
        dto: CreateBrandDto
    ): Promise<Brand | Error> {
        try {
            const entity = this.create({
                brandName: dto.brandName
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByBrandName(brandName: string): Promise<any | Error> {
        try {
            return await this.find({
                where: { 
                    brandName: brandName, 
                    isDeleted: false 
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(
        id: string
    ): Promise<Brand | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateBrand(
        id: string,
        dto: UpdateBrandDto
    ): Promise<Brand | Error> {
        try {
            await this.update(id, {
                brandName: dto.brandName
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<Brand[] | Error> {
        try {
            return await this.find({
                order: { brandName: 1 },
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(Brand)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async exportAllBrand(): Promise<Brand[] | Error> {
        try {
            return await this.find({
                    order: { 
                        createdAt: "DESC" 
                    },
                    where: { 
                        isDeleted: false 
                    }
                }
            );
        } catch (e) {
            return e;
        }
    }
}