import { EntityRepository, getConnection, Repository } from "typeorm";
import { ProductOffersEntity } from "./entities/product-offers.entity";
import { CreateProductOffersDto } from "./dto/create-product-offers.dto";
import { UpdateProductOffersDto } from "./dto/update-product-offers.dto";

@EntityRepository(ProductOffersEntity)
export class ProductOffersRepository extends Repository<ProductOffersEntity> {
    async createEntity(dto: CreateProductOffersDto): Promise<ProductOffersEntity | Error> {
        try {
            const {
                image,
                title
            } = dto;
            const entity = this.create({
                image,
                title
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductOffersEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductOffersEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<ProductOffersEntity[] | Error> {
        try {
            return await this.find({
                order: {
                    createdAt: "ASC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ProductOffersEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateProductOffersDto): Promise<ProductOffersEntity | Error> {
        try {
            await this.update(id, {
                image: dto.image,
                title: dto.title
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByTitle(title: string): Promise<ProductOffersEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    title: title,
                    isDeleted: false
                }
            });
        }
        catch (e) {
            return e;
        }
    }
}